.. _tweakutils:

******************************************
TWEAKUTILS: Utility Functions for Tweakreg
******************************************
The functions in this module support the various aspects of tweakreg, including finding the objects in the images and plotting the residuals.
    
.. automodule:: drizzlepac.tweakutils
   :members:
